@@ -2,7 +2,7 @@
 /// TODO: Documentation comments.
 
 use std::{fmt, future::Future};
-use tokio::sync::futures::Notified;
+use async_channel::Receiver;
 
 #[derive(Debug, PartialEq, Eq)]
 pub struct InterruptError { }
@@ -20,41 +20,41 @@ impl fmt::Display for InterruptError {
 }
 
 /// You usually use `interruptible` or `interruptible_sendable` instead.
-pub async fn interruptible_straight<'a, T, E: From<InterruptError>>(
-    notified: Notified<'a>,
+pub async fn interruptible_straight<T, E: From<InterruptError>>(
+    rx: Receiver<()>,
     f: impl Future<Output=Result<T, E>>
 ) -> Result<T, E>
 {
     tokio::select!{
         r = f => r,
         _ = async { // shorten lock lifetime
-            let _ = notified.await;
+            let _ = rx.recv().await;
         } => Err(InterruptError::new().into()),
     }
 }
 
-pub async fn interruptible<'a, T, E: From<InterruptError>>(
-    notified: Notified<'a>,
+pub async fn interruptible<T, E: From<InterruptError>>(
+    rx: Receiver<()>,
     f: impl Future<Output=Result<T, E>> + Unpin
 ) -> Result<T, E>
 {
-    interruptible_straight(notified, f).await
+    interruptible_straight(rx, f).await
 }
 
-pub async fn interruptible_sendable<'a, T, E: From<InterruptError>>(
-    notified: Notified<'a>,
+pub async fn interruptible_sendable<T, E: From<InterruptError>>(
+    rx: Receiver<()>,
     f: impl Future<Output=Result<T, E>> + Send + Unpin
 ) -> Result<T, E>
 {
-    interruptible_straight(notified, f).await
+    interruptible_straight(rx, f).await
 }
 
 /// TODO: More tests.
 #[cfg(test)]
 mod tests {
     use std::future::Future;
+    use async_channel::bounded;
     use futures::executor::block_on;
-    use tokio::sync::Notify;
 
     use crate::{InterruptError, interruptible, interruptible_sendable};
 
@@ -88,18 +88,16 @@ mod tests {
             }
         }
         pub async fn g(self) -> Result<u8, MyError> {
-            let notify = Notify::new();
-            let notified = notify.notified();
+            let (_tx, rx) = bounded(1);
 
-            interruptible(notified, Box::pin(async move {
+            interruptible(rx, Box::pin(async move {
                 Ok(123)
             })).await
         }
         pub async fn h(self) -> Result<u8, MyError> {
-            let notify = Notify::new();
-            let notified = notify.notified();
+            let (_tx, rx) = bounded(1);
 
-            interruptible(notified, Box::pin(async move {
+            interruptible(rx, Box::pin(async move {
                 Err(AnotherError::new().into())
             })).await
         }
@@ -119,11 +117,10 @@ mod tests {
 
     #[test]
     fn check_interruptible_sendable() {
-        let notify = Notify::new();
-        let notified = notify.notified();
+        let (_tx, rx) = bounded(1);
 
         // Check that `interruptible_sendable(...)` is a `Send` future.
-        let _: &(dyn Future<Output = Result<i32, InterruptError>> + Send) = &interruptible_sendable(notified, Box::pin(async move {
+        let _: &(dyn Future<Output = Result<i32, InterruptError>> + Send) = &interruptible_sendable(rx, Box::pin(async move {
             Ok(123)
         }));
     }
